Class: Google::Cloud::ParameterManager::V1::Parameter
- Inherits:
-
Object
- Object
- Google::Cloud::ParameterManager::V1::Parameter
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/parametermanager/v1/service.rb
Overview
Message describing Parameter resource
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#format ⇒ ::Google::Cloud::ParameterManager::V1::ParameterFormat
Optional.
-
#kms_key ⇒ ::String
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Identifier.
-
#policy_member ⇒ ::Google::Iam::V1::ResourcePolicyMember
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. [Output only] Create time stamp.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'proto_docs/google/cloud/parametermanager/v1/service.rb', line 52 class Parameter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#format ⇒ ::Google::Cloud::ParameterManager::V1::ParameterFormat
Returns Optional. Specifies the format of a Parameter.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'proto_docs/google/cloud/parametermanager/v1/service.rb', line 52 class Parameter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kms_key ⇒ ::String
Returns Optional. Customer managed encryption key (CMEK) to use for encrypting the
Parameter Versions. If not set, the default Google-managed encryption key
will be used. Cloud KMS CryptoKeys must reside in the same location as the
Parameter. The expected format is
projects/*/locations/*/keyRings/*/cryptoKeys/*.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'proto_docs/google/cloud/parametermanager/v1/service.rb', line 52 class Parameter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels as key value pairs.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'proto_docs/google/cloud/parametermanager/v1/service.rb', line 52 class Parameter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. [Output only] The resource name of the Parameter in the format
projects/*/locations/*/parameters/*.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'proto_docs/google/cloud/parametermanager/v1/service.rb', line 52 class Parameter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#policy_member ⇒ ::Google::Iam::V1::ResourcePolicyMember (readonly)
Returns Output only. [Output-only] policy member strings of a Google Cloud resource.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'proto_docs/google/cloud/parametermanager/v1/service.rb', line 52 class Parameter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. [Output only] Update time stamp.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'proto_docs/google/cloud/parametermanager/v1/service.rb', line 52 class Parameter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |