Class: Google::Cloud::ParameterManager::V1::ParameterVersion

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/parametermanager/v1/service.rb

Overview

Message describing ParameterVersion resource

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. [Output only] Create time stamp.

Returns:



231
232
233
234
# File 'proto_docs/google/cloud/parametermanager/v1/service.rb', line 231

class ParameterVersion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#disabled::Boolean

Returns Optional. Disabled boolean to determine if a ParameterVersion acts as a metadata only resource (payload is never returned if disabled is true). If true any calls will always default to BASIC view even if the user explicitly passes FULL view as part of the request. A render call on a disabled resource fails with an error. Default value is False.

Returns:

  • (::Boolean)

    Optional. Disabled boolean to determine if a ParameterVersion acts as a metadata only resource (payload is never returned if disabled is true). If true any calls will always default to BASIC view even if the user explicitly passes FULL view as part of the request. A render call on a disabled resource fails with an error. Default value is False.



231
232
233
234
# File 'proto_docs/google/cloud/parametermanager/v1/service.rb', line 231

class ParameterVersion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kms_key_version::String (readonly)

Returns Optional. Output only. [Output only] The resource name of the KMS key version used to encrypt the ParameterVersion payload. This field is populated only if the Parameter resource has customer managed encryption key (CMEK) configured.

Returns:

  • (::String)

    Optional. Output only. [Output only] The resource name of the KMS key version used to encrypt the ParameterVersion payload. This field is populated only if the Parameter resource has customer managed encryption key (CMEK) configured.



231
232
233
234
# File 'proto_docs/google/cloud/parametermanager/v1/service.rb', line 231

class ParameterVersion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. [Output only] The resource name of the ParameterVersion in the format projects/*/locations/*/parameters/*/versions/*.

Returns:

  • (::String)

    Identifier. [Output only] The resource name of the ParameterVersion in the format projects/*/locations/*/parameters/*/versions/*.



231
232
233
234
# File 'proto_docs/google/cloud/parametermanager/v1/service.rb', line 231

class ParameterVersion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#payload::Google::Cloud::ParameterManager::V1::ParameterVersionPayload

Returns Required. Immutable. Payload content of a ParameterVersion resource. This is only returned when the request provides the View value of FULL (default for GET request).

Returns:



231
232
233
234
# File 'proto_docs/google/cloud/parametermanager/v1/service.rb', line 231

class ParameterVersion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. [Output only] Update time stamp.

Returns:



231
232
233
234
# File 'proto_docs/google/cloud/parametermanager/v1/service.rb', line 231

class ParameterVersion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end